# Resources
from lob.resource import (Address, Area, BankAccount, Check, Letter, Postcard,
                          Route, USAutocompletion, USVerification, USZipLookup,
                          IntlVerification)

from lob.version import VERSION

api_key = None
api_base = 'https://api.lob.com/v1'
